

****************************************************************************************
*                                                                                      *
*                       Step 1. Clean Up Orbital Insight Data                          *
*                                                                                      *
****************************************************************************************;



libname REFINERY "&Dropbox\Data";




****************************************************************************************;
****************************************************************************************;


*import refinery data;
proc import datafile="&Dropbox\Data\orbital_refinery_2019_08_07.xlsx" 
  out=x1 dbms=xlsx replace;
  getnames=yes;
run;


*collect zip codes and gvkey of refineries;
data x2;
set x1;
  keep bbg_name refinery_name capacity;
proc sort data=x2 nodup;
  by bbg_name refinery_name;
run;



****************************************************************************************;

*Manual cleaning of refinery locations & matching to Compustat;
proc export outfile="&Dropbox\Data\refinery_orbital.xlsx" 
  data=x2 dbms=xlsx replace;
run;

****************************************************************************************;



proc import datafile="&Dropbox\Data\refinery_orbital_v1.xlsx" 
  out=x3 dbms=xlsx replace;
  getnames=yes;
run;


proc sql noprint;
  create table x4 as select distinct a.*, b.* from
  x1 as a left join x3 as b
  on a.bbg_name=b.bbg_name & a.refinery_name=b.refinery_name;
quit;


data x5;
set x4;
  where '01jan2017'd<=local_date<='30jun2019'd;
  weekend=(weekday(local_date) in (1, 7));*1 = Sunday, 2 = Monday, , 7 = Saturday;
proc sort data=x5 nodupkey;
  by id;
run;



*merge media coverage & bloomberg data;
proc import datafile="&Dropbox\Factiva\bbg_refo_media_v3.xlsx" 
  out=y1 dbms=xlsx replace;
  getnames=yes;
run;


*bloomberg data;
data y2;
set y1;
  where missing(coordinates)=0 & missing(start)=0 & missing(end)=0;
  bbg_planned=(type='P');
  bbg_interval=intck('day',start,end);
  keep coordinates type bbg_planned start end bbg_interval;
  rename type=bbg_type start=bbg_start end=bbg_end;
proc sort data=y2 nodup;
  by bbg_interval coordinates bbg_type bbg_start bbg_end;
run;


*merge bloomberg data;
proc sql noprint;
  create table y3 as select a.coordinates, a.local_date, a.abnormal, b.* from
  x5 as a left join y2 as b
  on a.coordinates=b.coordinates & b.bbg_start<=a.local_date<=b.bbg_end;
quit;


proc sort data=y3 nodup;
  by coordinates local_date bbg_start bbg_end bbg_type;
run;


proc means data=y3 noprint;
  by coordinates local_date;
  output out=y4 (drop=_type_ rename=(_freq_=bbg_freq)) 
  mean(bbg_planned)=bbg_planned
  min(bbg_start)=bbg_start max(bbg_end)=bbg_end;
run;


data y5;
set y4;
  bbg_abnormal=(bbg_start>. & bbg_end>.);
  bbg_interval=intck('day',bbg_start,bbg_end);
proc sort data=y5 nodupkey;
  by coordinates local_date;
run;



*media data;
data z1;
set y1;
  where missing(media_start_date)=0 & missing(media_end_date)=0;
  media_planned=(type='P');
  media_interval=intck('day',media_start_date, media_end_date);
  keep coordinates type media_planned media_num first_news_date last_news_date 
  media_start_date media_end_date media_interval;
  rename type=media_type;
proc sort data=z1 nodup;
  by media_interval coordinates media_start_date media_end_date;
run;


proc sql noprint;
  create table z2 as select a.coordinates, a.local_date, a.abnormal, b.* from
  x5 as a left join z1 as b
  on a.coordinates=b.coordinates & b.media_start_date<=a.local_date<=b.media_end_date;
quit;


proc sort data=z2 nodup;
  by coordinates local_date media_start_date media_end_date media_planned;
run;


proc means data=z2 noprint;
  by coordinates local_date;
  output out=z3 (drop=_type_ rename=(_freq_=media_freq)) 
  mean(media_planned)=media_planned
  min(media_start_date)=media_start max(media_end_date)=media_end
  min(first_news_date)=first_news max(last_news_date)=last_news;
run;


data z4;
set z3;
  media_abnormal=(media_start>. & media_end>.);
  media_interval=intck('day',media_start, media_end);
proc sort data=z4 nodupkey;
  by coordinates local_date;
run;



data y6;
merge y5 z4;
  by coordinates local_date;
  drop bbg_freq media_freq;
proc sort data=y6 nodupkey;
  by coordinates local_date;
run;



proc sql noprint;
  create table x6 as select a.*, b.* from
  x5 as a left join y6 as b
  on a.coordinates=b.coordinates & a.local_date=b.local_date;
quit;


proc sort data=x6 out=REFINERY.orbital_new nodupkey;
  by ticker id;
run;


proc datasets library=work kill; 
run;quit;













***************************************************************************************
*                                                                                     *
*                           Step 2. Download Financial Data                           *
*                                                                                     *
***************************************************************************************;


*DOWNLOAD FIRM FINANCIAL DATA;
data x1;
set REFINERY.orbital_new;
  where gvkey is not null;
  keep gvkey permno ticker padd;
  format gvkey $6.;
proc sort data=x1 nodupkey;
  by gvkey permno;
run;


*Compustat quarterly file;
%let wrds=wrds-cloud.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS;
signon username=_prompt_;
rsubmit;


libname COMP "/wrds/comp/sasdata/d_na" inencoding=asciiany;
libname CCM '/wrds/crsp/sasdata/a_ccm' inencoding=asciiany;

options sasautos=('/wrds/wrdsmacros/', SASAUTOS) MAUTOSOURCE;


proc upload data=x1 out=work.x1; run;


data work.x2;
set COMP.fundq; *(obs=2000);
  MVEQ=PRCCQ*CSHOQ;
  BVEQ=SEQQ;
  if SEQQ=. then BVEQ=sum(CEQQ,PSTKQ);
  if CEQQ=. then BVEQ=ATQ-LTQ;
  DEBTQ=sum(DLTTQ,DLCQ);
  keep GVKEY FYEARQ FQTR DATADATE RDQ ATQ SALEQ MVEQ BVEQ DEBTQ IBQ NIQ SPIQ COGSQ XSGAQ;
  where FYEARQ>=2012 & CONSOL='C' & INDFMT='INDL' & DATAFMT='STD' & POPSRC='D';
  rename FYEARQ=FYEAR;
proc sort data=work.x2 nodupkey;
  by GVKEY DATADATE;
run;


proc sql noprint;
  create table work.x3 as select distinct a.*, b.* from
  work.x2 as a left join work.x1 as b
  on a.gvkey=b.gvkey;
quit;


data work.x4;
set work.x3;
  where padd is not null;
proc sort data=work.x4 nodup;
  by gvkey datadate;
run;

proc download data=work.x4 out=x2; run;

proc datasets library=work kill; 
run;quit;

endrsubmit;



proc sort data=x2 out=x3 nodupkey;
  by gvkey datadate;
run;


proc sql noprint;
  create table x4 as select distinct a.*, b.DATADATE as DATADATE_L1, b.RDQ as RDQ_L1, 
  b.IBQ as IBQ_L1, b.SALEQ as SALEQ_L1, b.BVEQ as BVEQ_L1, b.MVEQ as MVEQ_L1, b.ATQ as ATQ_L1, b.DEBTQ as DEBTQ_L1 from
  x2 as a left join x3 as b
  on a.gvkey=b.gvkey & intck('qtr',b.datadate,a.datadate)=1;
quit;


proc sql noprint;
  create table x5 as select distinct a.*, b.DATADATE as DATADATE_L4, b.IBQ as IBQ_L4, b.SALEQ as SALEQ_L4,
  b.BVEQ as BVEQ_L4, b.MVEQ as MVEQ_L4, b.ATQ as ATQ_L4 from
  x4 as a left join x3 as b
  on a.gvkey=b.gvkey & intck('qtr',b.datadate,a.datadate)=4;
quit;


data x6;
  informat gvkey permno ticker fyear fqtr datadate rdq;
set x5;
proc sort data=x6 out=REFINERY.rr2_fundq nodupkey;
  by gvkey datadate;
run;


proc datasets library=work kill; 
run;quit;










***************************************************************************************
*                                                                                     *
*                      Step 3. Download Daily Stock Return Data                       *
*                                                                                     *
***************************************************************************************;


*DOWNLOAD DAILY STOCK RETURN DATA;
*keep public refineries;
data x1;
set REFINERY.orbital_new;
  where missing(permno)=0;
  permno1=permno+0;
  keep permno1 local_date;
  rename permno1=permno local_date=date;
proc sort data=x1 nodupkey;
  by permno date;
run;


proc means data=x1 noprint;
  by permno;
  output out=x2 (drop=_type_) min(date)=min_date max(date)=max_date;
run;


data x3;
set x2;
  beg_date=intnx('month',min_date,-18,'b');
  end_date=intnx('month',max_date,+18,'e');
  format beg_date end_date mmddyy10.;
proc sort data=x3 nodupkey;
  by permno;
run;



*==========================================================*;

*remote connection to WRDS;
%let wrds=wrds-cloud.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS;
signon username=_prompt_;
rsubmit;

libname CRSP "/wrds/crsp/sasdata/a_stock" inencoding=asciiany;
libname FF "/wrds/ff/sasdata" inencoding=asciiany;


proc upload data=x3 (keep=permno beg_date end_date) out=work.x1; run;


*daily returns;
proc sql noprint;
  create table work.x2 as select distinct a.*, b.date, b.hsiccd, b.hexcd, 
  (b.ret+0) as ret, abs(b.prc) as prc, b.shrout from
  work.x1 as a, CRSP.dsf as b
  where a.permno=b.permno & a.beg_date<=b.date<=a.end_date
  order by a.permno, b.date;
quit;


*delisting codes & delisting returns;
proc sql noprint;
  create table work.x3 as select distinct a.*, b.dlstcd, b.dlret from
  work.x2 as a left join CRSP.dsedelist as b
  on a.permno=b.permno & a.date=b.dlstdt
  order by permno, date;
quit;


*incorporate market Return;
proc sql noprint;
  create table work.x4 as select distinct a.*, b.* from
  work.x3 as a left join FF.factors_daily as b
  on a.date=b.date
  order by a.permno, a.date;
quit;


data work.x5;
set work.x4;
*returns & delisting returns;
  if dlstcd=500 or 505<=dlstcd<=588 then do;
  if hexcd<=2 and dlret=. then dlret= -0.30; 
  if hexcd= 3 and dlret=. then dlret= -0.50; end;
  if dlret>-1 and ret<=. then ret=dlret;
  drop beg_date end_date dlstcd dlret;
  format ret prc 9.6;
proc sort data=work.x5 nodupkey;
  by permno date;
run;


proc download data=work.x5 out=REFINERY.rr2_dsf; run;

proc datasets library=work kill; 
run;quit;

endrsubmit;

*==========================================================*;



*Calculate earnings announcement returns;
data y1;
set REFINERY.rr2_fundq;
  where missing(permno)=0 & '01jan2015'd<=datadate<='31dec2020'd;
  permno1=permno+0;
  keep permno permno1 datadate ticker rdq;
  format datadate rdq mmddyy10.;
proc sort data=y1 nodupkey;
  by permno datadate;
run;


*merge IBES earnings announcement dates;
proc sql noprint;
  create table y2 as select distinct a.*, b.anndats as rdq_ibes from
  y1 as a left join REFINERY.rr2_ibes as b
  on a.ticker=b.oftic & a.datadate=b.pends;
quit;


data y3;
set y2;
  if missing(rdq_ibes)=0 & rdq>=rdq_ibes then rdq1=rdq_ibes;
  else rdq1=rdq;
  format rdq1 mmddyy10.;
  drop rdq rdq_ibes;
  rename rdq1=rdq;
proc sort data=y3 nodupkey;
  by permno datadate;
run;


*merge daily returns;
proc sql noprint;
  create table y4 as select distinct a.*, b.date, b.ret, (b.mktrf+b.rf) as mkt, intck('weekday',a.rdq,b.date) as gap from
  y3 as a left join REFINERY.rr2_dsf as b
  on a.permno1=b.permno & -5<=intck('weekday',a.rdq,b.date)<=+5
  order by a.permno, a.datadate, b.date;
quit;


data y5;
set y4;
  where missing(ret)=0;
  by permno datadate;
  retain time;
  if first.permno then time=1;
  else time=time+1;
  logR=log(ret+1);
  logM=log(mkt+1);
  aret=ret-mkt;
  drop permno1;
proc sort data=y5 nodupkey;
  by permno datadate gap;
run;


*find day zero;
data y6;
set y5;
  where gap>=0;
run;

proc sql noprint;
  create table y7 as select * from y6
  group by permno, datadate
  having gap=min(gap);
quit;


proc sql noprint;
  create table y8 as select distinct a.*, (a.time-b.time) as window from
  y5 as a left join y7 as b
  on a.permno=b.permno & a.datadate=b.datadate;
quit;


data y9;
set y8;
  where -2<=window<=2;
  drop time gap;
proc sort data=y9 nodupkey;
  by permno datadate rdq window;
run;


proc means data=y9 noprint;
  by permno datadate rdq;
  output out=z1 (drop=_type_ rename=(_freq_=freq_rdq))
  sum(aret logR logM)=car_rdq sum_logR sum_logM
  min(date)=date1 max(date)=date2;
run;


*merge oil index;
proc sql noprint;
  create table z2 as select distinct a.*, b.oil_index as oil_index1 from
  z1 as a left join REFINERY.oil_index as b
  on b.beg_date<=a.date1<=b.end_date;
quit;


proc sql noprint;
  create table z3 as select distinct a.*, b.oil_index as oil_index2 from
  z2 as a left join REFINERY.oil_index as b
  on b.beg_date<=a.date2<=b.end_date;
quit;



data z3;
set z3;
  ret_rdq=exp(sum_logR)-1;
  mkt_rdq=exp(sum_logM)-1;
  oil_chg_pct=(oil_index2-oil_index1)/oil_index1;
  format car_rdq ret_rdq mkt_rdq oil_chg_pct percent7.4;
  drop sum_logR sum_logM date1 date2 oil_index1 oil_index2;
proc sort data=z3 out=REFINERY.rr2_dsf1 nodupkey;
  by permno datadate;
run;


proc datasets library=work kill; 
run;quit;












***************************************************************************************
*                                                                                     *
*                     Step 4. Download Monthly Stock Return Data                      *
*                                                                                     *
***************************************************************************************;


*DOWNLOAD MONTHLY STOCK RETURN DATA;
*keep public refineries;
data x1;
set REFINERY.orbital_new;
  where missing(permno)=0;
  permno1=permno+0;
  keep permno1 local_date;
  rename permno1=permno local_date=date;
proc sort data=x1 nodupkey;
  by permno date;
run;


proc means data=x1 noprint;
  by permno;
  output out=x2 (drop=_type_) min(date)=min_date max(date)=max_date;
run;


data x3;
set x2;
  beg_date=intnx('month',min_date,-18,'b');
  end_date=intnx('month',max_date,+18,'e');
  format beg_date end_date mmddyy10.;
proc sort data=x3 nodupkey;
  by permno;
run;



*==========================================================*;

*remote connection to WRDS;
%let wrds=wrds-cloud.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS;
signon username=_prompt_;
rsubmit;

libname CRSP "/wrds/crsp/sasdata/a_stock" inencoding=asciiany;
libname FF "/wrds/ff/sasdata" inencoding=asciiany;


proc upload data=x3 (keep=permno beg_date end_date) out=work.x1; run;


*daily returns;
proc sql noprint;
  create table work.x2 as select distinct a.*, b.date, b.hsiccd, b.hexcd, 
  (b.ret+0) as ret, abs(b.prc) as prc, b.shrout from
  work.x1 as a, CRSP.msf as b
  where a.permno=b.permno & a.beg_date<=b.date<=a.end_date
  order by a.permno, b.date;
quit;


*delisting codes & delisting returns;
proc sql noprint;
  create table work.x3 as select distinct a.*, b.dlstcd, b.dlret from
  work.x2 as a left join CRSP.msedelist as b
  on a.permno=b.permno & a.date=b.dlstdt
  order by permno, date;
quit;


*incorporate market Return;
proc sql noprint;
  create table work.x4 as select distinct a.*, b.* from
  work.x3 as a left join FF.factors_monthly as b
  on intck('month',b.date,a.date)=0
  order by a.permno, a.date;
quit;


data work.x5;
set work.x4;
*returns & delisting returns;
  if dlstcd=500 or 505<=dlstcd<=588 then do;
  if hexcd<=2 and dlret=. then dlret= -0.30; 
  if hexcd= 3 and dlret=. then dlret= -0.50; end;
  if dlret>-1 and ret<=. then ret=dlret;
  drop beg_date end_date dlstcd dlret;
  format ret prc 9.6;
proc sort data=work.x5 nodupkey;
  by permno date;
run;


proc download data=work.x5 out=REFINERY.rr2_msf; run;

proc datasets library=work kill; 
run;quit;

endrsubmit;

*==========================================================*;


*Calculate future returns;
data x4;
set REFINERY.rr2_msf;
  mktcap=abs(prc*shrout)/1000;
  format ret percent7.4 mktcap 15.2;
proc sort data=x4 nodupkey;
  by permno date;
run;



*future returns;
proc printto log="C:\Users\Bin Li\Documents\SAS Log\temp.log"; run;
proc expand data=x4 out=x5 method=none;
  by permno; id date;
  convert mktcap=mktcap_l1 / transformout=(lag 1);
  convert ret=ret_f1 / transformout=(lead 1);
  convert ret=ret_f2 / transformout=(lead 2);
  convert ret=ret_f3 / transformout=(lead 3);
  convert ret=ret_f4 / transformout=(lead 4);
  convert ret=ret_f5 / transformout=(lead 5);
  convert ret=ret_f6 / transformout=(lead 6);
  convert ret=ret_f7 / transformout=(lead 7);
  convert ret=ret_f8 / transformout=(lead 8);
  convert ret=ret_f9 / transformout=(lead 9);
run;
proc printto;run;



data x6;
  informat permno date dateff hsiccd hexcd prc shrout mktcap mktcap_l1 rf mktrf smb hml umd ret;
set x5;
  where date>='01jan2017'd;
  ret_m1=ret_f1;
  ret_m2=exp(log(1+ret_m1)+log(1+ret_f2))-1;
  ret_m3=exp(log(1+ret_m2)+log(1+ret_f3))-1;
  ret_m4=exp(log(1+ret_m3)+log(1+ret_f4))-1;
  ret_m5=exp(log(1+ret_m4)+log(1+ret_f5))-1;
  ret_m6=exp(log(1+ret_m5)+log(1+ret_f6))-1;
  ret_m7=exp(log(1+ret_m6)+log(1+ret_f7))-1;
  ret_m8=exp(log(1+ret_m7)+log(1+ret_f8))-1;
  ret_m9=exp(log(1+ret_m8)+log(1+ret_f9))-1;
  format ret_f1-ret_f9 ret_m1-ret_m9 percent7.4;
  drop year month; rename ret=ret_m0;
proc sort data=x6 out=REFINERY.rr2_msf1 nodupkey;
  by permno date;
run;

proc datasets library=work kill; 
run;quit;












************************************************************************************
*                                                                                  *
*               Step 5. Import EIA Oil Cost & Gasoline Stock Data                  *
*                                                                                  *
************************************************************************************;


*import Refiner Acquisition Cost of Crude Oil: EIA data;
proc import datafile="&Dropbox\Data\PET_PRI_RAC2_A_EPC0_PCT_DPBBL_M.xlsx" 
  out=x1 dbms=xlsx replace;
  getnames=yes;
run;


data x2;
set x1;
  where '01jan2015'd<=Date<='31dec2019'd;
  drop US;
proc sort data=x2 nodupkey;
  by Date;
run;


proc transpose data=x2 out=x3;
  by Date;
run;


data x4;
set x3;
  PADD=_NAME_;
  Date1=intnx('month',Date,0,'e');
  Acq_cost=COL1;
  format PADD $6. Date1 mmddyy10.;
  drop _NAME_ _LABEL_ Date COL1;
  rename Date1=Date;
proc sort data=x4 nodupkey;
  by PADD Date;
run;



*EIA gasoline stock data;
proc import datafile="&Dropbox\Data\PET_STOC_TS_A_EPM0_SAE_MBBL_M.xlsx" 
  out=y1 dbms=xlsx replace;
  getnames=yes;
run;


data y2;
set y1;
  where '01jan2015'd<=Date<='31dec2019'd;
  drop US;
proc sort data=y2 nodupkey;
  by Date;
run;


proc transpose data=y2 out=y3;
  by Date;
run;


data y4;
set y3;
  PADD=_NAME_;
  Date1=intnx('month',Date,0,'e');
  Gas_stock=COL1;
  format PADD $6. Date1 mmddyy10.;
  drop _NAME_ _LABEL_ Date COL1;
  rename Date1=Date;
proc sort data=y4 nodupkey;
  by PADD Date;
run;


data z1;
merge x4 y4;
  by PADD Date;
proc sort data=z1 out=REFINERY.oil_acq_cost nodupkey;
  by PADD Date;
run;


proc datasets library=work kill; 
run;quit;




*import firm-level capacity data;
proc import datafile="&Dropbox\Data\firm_capacity.xlsx" 
  out=x1 dbms=xlsx replace;
  getnames=yes;
run;


proc sort data=x1 out=REFINERY.firm_capacity nodupkey;
  by Ticker Date_beg;
run;


proc datasets library=work kill; 
run;quit;










************************************************************************************
*                                                                                  *
*                      Step 6. Import GasBuddy Gas Price Data                      *
*                                                                                  *
************************************************************************************;


*import GasBuddy data;
proc import datafile="&Dropbox\Data\gasbuddy_combined.xlsx" 
  out=x1 dbms=xlsx replace;
  getnames=yes;
run;

proc sort data=x1;
  by city date;
run;

proc means data=x1 noprint;
  by city date;
  output out=x2 median(price)=price;
run;

proc sort data=x2 nodupkey;
  by city date;
run;


proc freq data=x2 noprint;
  tables city*date / sparse out=x3 (keep=city date);
run;


proc sql noprint;
  create table x4 as select a.*, b.price from
  x3 as a left join x2 as b
  on a.city=b.city & a.date=b.date;
quit;


proc sort data=x4 out=REFINERY.gasbuddy nodupkey;
  by city date;
run;


proc datasets library=work kill; 
run;quit;











****************************************************************************************
*                                                                                      *
*                 Step 7. Create a Sample for Descriptive Statistics                   *
*                                                                                      *
****************************************************************************************;


*Deal with weekends & holidays;
data x1;
set Refinery.rr2_dsf;
  keep date;
proc sort data=x1 nodupkey;
  by date;
run;


proc sql noprint;
  create table x2 as select a.coordinates, a.local_date, a.abnormal, b.* from
  REFINERY.orbital_new as a left join x1 as b
  on a.local_date=b.date;
quit;



data x3;
set x2;
  weekend_holiday=(date=.);
proc sort data=x3 nodupkey;
  by coordinates local_date;
run;


data y1;
set x3;
  by coordinates local_date;
  retain date1;
  if first.coordinates | date>. then date1=date;
  format date1 yymmddn8.;
proc sort data=y1 nodupkey;
  by coordinates descending local_date;
run;


data y2;
set y1;
  by coordinates descending local_date;
  retain date2;
  if first.coordinates | date>. then date2=date;
  format date2 yymmddn8.;
  if local_date<='02jan2017'd then date1='01jan2017'd;
  if local_date>='29jun2019'd then date2='30jun2019'd;
proc sort data=y2 nodupkey;
  by coordinates local_date;
run;


proc sql noprint;
  create table y3 as select a.*, b.abnormal as abn1 from
  y2 as a left join x3 as b
  on a.coordinates=b.coordinates & a.date1=b.local_date;
quit;


proc sql noprint;
  create table y4 as select a.*, b.abnormal as abn2 from
  y3 as a left join x3 as b
  on a.coordinates=b.coordinates & a.date2=b.local_date
  order by a.coordinates, a.local_date;
quit;



data y5;
set y4;
  oi_abnormal=abnormal;
  if weekend_holiday=1 & abnormal=0 then do;
     if abn1=1 & abn2=1 then oi_abnormal=1;end;
proc sort data=y5 nodupkey;
  by coordinates local_date;
run;



proc sql noprint;
  create table y6 as select a.*, b.oi_abnormal, b.weekend_holiday from
  REFINERY.orbital_new as a left join y5 as b
  on a.coordinates=b.coordinates & a.local_date=b.local_date;
quit;


*LyondellBasell Channelview Refinery is removed (29.817524, -95.114604): Under construction
https://ohsonline.com/articles/2017/07/21/lyondellbasell-to-build-texas-plant.aspx;
data y6;
set y6;
  if coordinates="29.817524, -95.114604" then delete;
proc sort data=y6 out=REFINERY.rr2_orbital nodupkey;
  by id;
run;


proc datasets library=work kill; 
run;quit;


*export SAS file to STATA file;
proc export data=REFINERY.rr2_orbital
  file="&Dropbox\Data\rr2_orbital"
  dbms=stata replace;
run;









***************************************************************************************
*                                                                                     *
*                    Step 8. Create a Sample for Gas Price Tests                      *
*                                                                                     *
***************************************************************************************;


*Refinery data;
data x1;
set REFINERY.rr2_orbital;
  where missing(city)=0;
  public=(type="public");
  rename local_date=date; 
  drop abnormal;
proc sort data=x1 nodupkey;
  by id permno date;
run;



data x2;
set x1;
  abn_cap_oi=oi_abnormal*capacity;
  abn_cap_bbg=bbg_abnormal*capacity;
  abn_cap_media=media_abnormal*capacity;
proc sort data=x2 nodupkey;
  by coordinates date;
run;


proc sort data=x2 nodupkey;
  by padd city date coordinates;
run;



*aggregate at the city-date level;
proc means data=x2 noprint;
  by padd city date;
  output out=x3 (drop=_type_ rename=(_freq_=city_refinery_freq))
  median(weekend_holiday)=weekend_holiday
  sum(capacity abn_cap_oi abn_cap_bbg abn_cap_media)=
      city_tot_cap city_abn_cap_oi city_abn_cap_bbg city_abn_cap_media;
run;



*aggregate at the city-date level: value-weigthed;
proc means data=x2 noprint;
  by padd city date;
  weight capacity;
  output out=x4 (drop=_type_ _freq_)
  mean(oi_abnormal bbg_abnormal media_abnormal)=abn_vw_oi abn_vw_bbg abn_vw_media;
run;



data x5;
merge x3 x4;
  by padd city date;
  abn_pct_oi=city_abn_cap_oi/city_tot_cap;
  abn_pct_bbg=city_abn_cap_bbg/city_tot_cap;
  abn_pct_media=city_abn_cap_media/city_tot_cap;
  drop city_abn_cap_oi city_abn_cap_bbg city_abn_cap_media;
  format abn_pct_oi abn_pct_bbg abn_pct_media abn_vw_oi abn_vw_bbg abn_vw_media 10.3;
proc sort data=x5 nodupkey;
  by city date;
run;



*merge with gas price data;
proc sql noprint;
  create table x6 as select distinct a.*, b.* from
  REFINERY.gasbuddy_clean as a left join x5 as b
  on a.city=b.city & a.date=b.date;
quit;


*merge EIA oil acquisition cost data;
proc sql noprint;
  create table x7 as select distinct a.*, b.date as date1, b.acq_cost, b.gas_stock from
  x6 as a left join REFINERY.oil_acq_cost as b
  on a.padd=b.padd & intck('month',b.date,a.date)=1;
quit;


*merge OIL index;
proc sql noprint;
  create table x8 as select distinct a.*, b.oil_index from
  x7 as a left join REFINERY.oil_index as b
  on b.beg_date<=a.date<=b.end_date;
quit;



*We exclue Baton Rouge because it's less than 100 miles from New Orleans;
data x9;
set x8;
  where '01jan2017'd<=date<='31dec2019'd;
  if missing(price)=0;
  if abn_pct_oi>. then abn_dum_oi=(abn_pct_oi>0);
  if abn_pct_bbg>. then abn_dum_bbg=(abn_pct_bbg>0);
  if abn_pct_media>. then abn_dum_media=(abn_pct_media>0);
  drop date1 abn_vw_oi abn_vw_bbg abn_vw_media;
proc sort data=x9 out=REFINERY.rr2_gas_price_test nodupkey;
  by city date;
run;


proc datasets library=work kill; 
run;quit;




*export SAS file to STATA file;
proc export data=REFINERY.rr2_gas_price_test
  file="&Dropbox\Data\rr2_gas_price_test.dta"
  dbms=stata replace;
run;











*************************************************************************************
*                                                                                   *
*               Step 9. Create a Sample for Financial Performance Tests             *
*                                                                                   *
*************************************************************************************;



*Refinery data;
data x1;
set REFINERY.rr2_orbital;
  where missing(permno)=0;
  permno1=permno+0;
  planned=(bbg_planned=1);
  abn_oi_planned=oi_abnormal*planned;
  abn_oi_unplanned=oi_abnormal-abn_oi_planned;
  ref_cap1k=capacity/1000;
  rename oi_abnormal=abn_oi bbg_abnormal=abn_bbg media_abnormal=abn_media local_date=date;
  drop first_date last_date abnormal;
  format ref_cap1k 10.1;
proc sort data=x1 nodupkey;
  by permno date coordinates;
run;


*merge EIA oil acquisition price data;
proc sql noprint;
  create table x2 as select distinct a.*, b.date as date1, b.acq_cost, b.gas_stock from
  x1 as a left join REFINERY.oil_acq_cost as b
  on a.padd=b.padd & intck('month',b.date,a.date)=1;
quit;


proc sort data=x2 nodupkey;
  by gvkey date coordinates;
run;



*Compustat quarterly data;
data y1;
set REFINERY.rr2_fundq;
  where rdq>.;
  if SPIQ=. then SPIQ=0;
  if SPIQ<0 then NEG_SPIQ=abs(SPIQ);
  if SPIQ>=0 then NEG_SPIQ=0;
  ROAQ=IBQ/ATQ_L1;
  ATOQ=SALEQ/ATQ_L1;
  NEG_SPI_ATQ=NEG_SPIQ/ATQ_L1;
  LEVQ=DEBTQ/ATQ;
  BTMQ=BVEQ/MVEQ;
  SALEQ_GR=(SALEQ/SALEQ_L4)-1;
  format ROAQ ATOQ NEG_SPI_ATQ LEVQ BTMQ SALEQ_GR 10.3;
proc sort data=y1 nodupkey;
  by gvkey datadate;
run;


data y2;
set y1;
  by gvkey datadate;
  LEVQ_L1=lag(LEVQ);
  BTMQ_L1=lag(BTMQ);
  if first.gvkey then do; 
  LEVQ_L1=.; BTMQ_L1=.; end;
proc sort data=y2 nodupkey;
  by gvkey datadate;
run;



*merge Orbital Insight data;
proc sql noprint;
  create table x3 as select distinct a.gvkey, a.datadate, a.datadate_l1, b.* from
  y2 as a left join x2 as b
  on a.gvkey=b.gvkey & a.datadate_l1<b.date<=a.datadate
  order by a.gvkey, a.datadate, b.date;
quit;



data x4;
set x3;
  where missing(abn_oi)=0;
proc sort data=x4 nodupkey;
  by gvkey datadate datadate_l1 date coordinates;
run;



*quarterly abnormal percentage;
*weighted by raw refinery capacity;
proc means data=x4 noprint;
  by gvkey datadate datadate_l1;
  weight ref_cap1k;
  output out=x5 (drop=_type_ _freq_)
  mean(abn_oi abn_bbg abn_media abn_oi_planned abn_oi_unplanned acq_cost gas_stock)=
  abn_pct_oi abn_pct_bbg abn_pct_media abn_pct_oi_planned abn_pct_oi_unplanned acq_cost_vw gas_stock_vw;
run;



*firm-level averages;
proc means data=x4 noprint;
  by gvkey datadate datadate_l1 date;
  output out=z1 (drop=_type_ rename=(_freq_=refinery_num))
  sum(ref_cap1k)=ref_cap1k;
run;


*merge firm total capacity;
proc sql noprint;
  create table z2 as select distinct a.*, b.capacity1k as firm_cap1k from
  z1 as a left join REFINERY.firm_capacity as b
  on a.gvkey=b.gvkey & b.date_beg<=a.date<=b.date_end;
quit;


*merge OIL index;
proc sql noprint;
  create table z3 as select distinct a.*, b.oil_index format 10.2 from
  z2 as a left join REFINERY.oil_index as b
  on b.beg_date<=a.date<=b.end_date;
quit;


proc sort data=z3 nodupkey;
  by gvkey datadate datadate_l1 date;
run;


proc means data=z3 noprint;
  by gvkey datadate datadate_l1;
  output out=z4 (drop=_type_ rename=(_freq_=freq_qtr))
  median(refinery_num)=refinery_num
  mean(ref_cap1k firm_cap1k oil_index)=ref_cap1k firm_cap1k oil_index;
run;


data x6;
merge x5 z4;
  by gvkey datadate datadate_l1;
  if firm_cap1k<ref_cap1k then firm_cap1k=ref_cap1k;
  ref_cap_pct=ref_cap1k/firm_cap1k;
  format abn_pct_oi abn_pct_bbg abn_pct_media abn_pct_oi_planned abn_pct_oi_unplanned 10.3 acq_cost_vw gas_stock_vw 10.2 ref_cap_pct percent7.4;
proc sort data=x6 nodupkey;
  by gvkey datadate;
run;



*merge firm fundamentals;
proc sql noprint;
  create table x7 as select distinct a.*, b.* from
  x6 as a left join y2 as b
  on a.gvkey=b.gvkey & a.datadate=b.datadate;
quit;



*merge earnings announcement returns;
proc sql noprint;
  create table x8 as select distinct a.*, b.car_rdq, b.ret_rdq, b.mkt_rdq, b.oil_chg_pct from 
  x7 as a left join REFINERY.rr2_dsf1 as b
  on a.permno=b.permno & a.datadate=b.datadate;
quit;


proc sort data=x8 out=REFINERY.rr2_roa_test nodupkey;
  by gvkey datadate;
run;


proc datasets library=work kill; 
run;quit;



*export SAS file to STATA file;
proc export data=REFINERY.rr2_roa_test
  file="&Dropbox\Data\rr2_roa_test.dta"
  dbms=stata replace;
run;












*************************************************************************************
*                                                                                   *
*                 Step 10. Create a Sampel for Media Coverage Tests                 *
*                                                                                   *
*************************************************************************************;


*Refinery data;
data x1;
set REFINERY.rr2_orbital;
  where missing(city)=0;
  public=(type="public");
  time=intnx("&interval",local_date,0,'e');
  format time mmddyy10.;
  rename local_date=date;
  drop abnormal;
proc sort data=x1 nodupkey;
  by id permno date;
run;



data x2;
set x1;
  planned=(bbg_planned=1);
  abn_oi_planned=oi_abnormal*planned;
  abn_oi_unplanned=oi_abnormal-abn_oi_planned;
  rename oi_abnormal=abn_oi bbg_abnormal=abn_bbg media_abnormal=abn_media;
proc sort data=x2 nodupkey;
  by padd city refinery_name coordinates ticker time date;
run;



*aggregate at the refinery-time level;
proc means data=x2 noprint;
  by padd city refinery_name coordinates ticker time;
  output out=x3 (drop=_type_ rename=(_freq_=freq))
  median(public capacity)=public capacity
  mean(abn_oi abn_oi_planned abn_oi_unplanned abn_bbg abn_media)=abn_pct_oi abn_pct_oi_planned abn_pct_oi_unplanned abn_pct_bbg abn_pct_media;
run;


data x3;
merge x3;
  format abn_pct_oi abn_pct_oi_planned abn_pct_oi_unplanned abn_pct_bbg abn_pct_media 10.3;
proc sort data=x3 nodupkey;
  by coordinates time;
run;



*merge EIA oil acquisition cost data;
proc sql noprint;
  create table x4 as select distinct a.*, b.date as date1, b.acq_cost, b.gas_stock from
  x3 as a left join REFINERY.oil_acq_cost as b
  on a.padd=b.padd & intck("&interval",b.date,a.time)=1;
quit;



*merge OIL index;
proc sql noprint;
  create table x5 as select distinct a.*, b.oil_index from
  x4 as a left join REFINERY.oil_index as b
  on b.beg_date<=a.time<=b.end_date;
quit;


proc sort data=x5 nodupkey;
  by city time coordinates;
run;


*number of refineries in the city & total capacity;
proc means data=x5 noprint;
  by city time;
  output out=x6 (drop=_type_ rename=(_freq_=city_refinery))
  sum(capacity)=city_capacity;
run;


proc sql noprint;
  create table x7 as select distinct a.*, b.* from
  x5 as a left join x6 as b
  on a.city=b.city & a.time=b.time;
quit;


data x8;
set x7;
  format acq_cost gas_stock oil_index 10.2;
  drop date1;
proc sort data=x8 out=REFINERY.rr2_media_test_month nodupkey;
  by coordinates time;
run;



proc datasets library=work kill; 
run;quit;



*export SAS file to STATA file;
proc export data=REFINERY.rr2_media_test_month
  file="&Dropbox\Data\rr2_media_test_month"
  dbms=stata replace;
run;













*************************************************************************************
*                                                                                   *
*                  Step 11. Create a Sample for Stock Return Tests                  *
*                                                                                   *
*************************************************************************************;


%let interval=month;
*%let interval=qtr;


*keep public refineries;
data x1;
set REFINERY.rr2_orbital;
  where missing(permno)=0;
  permno1=permno+0;
  time=intnx("&interval",local_date,0,'e');
  planned=(bbg_planned=1);
  abn_oi_planned=oi_abnormal*planned;
  abn_oi_unplanned=oi_abnormal-abn_oi_planned;
  ref_cap1k=capacity/1000;
  rename oi_abnormal=abn_oi bbg_abnormal=abn_bbg media_abnormal=abn_media local_date=date;
  format time mmddyy10. ref_cap1k 10.1;
  drop first_date last_date abnormal;
proc sort data=x1 nodupkey;
  by permno date coordinates;
run;


*merge EIA oil acquisition price data;
proc sql noprint;
  create table x2 as select distinct a.*, b.date as date1, b.acq_cost, b.gas_stock from
  x1 as a left join REFINERY.oil_acq_cost as b
  on a.padd=b.padd & intck('month',b.date,a.date)=1;
quit;


proc sort data=x2 nodupkey;
  by permno time date coordinates;
run;


*simple average;
proc means data=x2 noprint;
  by permno time date;
  output out=x3 (drop=_type_ rename=(_freq_=refinery_freq))
  sum(ref_cap1k)=ref_cap1k;
run;


*merge firm total capacity;
proc sql noprint;
  create table x4 as select distinct a.*, b.capacity1k as firm_cap1k from
  x3 as a left join REFINERY.firm_capacity as b
  on a.permno=b.permno & b.date_beg<=a.date<=b.date_end;
quit;


proc sort data=x4 nodupkey;
  by permno time date;
run;


proc means data=x4 noprint;
  by permno time;
  output out=x5 (drop=_type_ _freq_)
  median(refinery_freq)=refinery_freq mean(ref_cap1k firm_cap1k)=ref_cap1k firm_cap1k;
run;



*capacity weighted;
proc means data=x2 noprint;
  by permno time;
  weight capacity;
  output out=x6 (drop=_type_ _freq_)
  mean(abn_oi abn_bbg abn_media abn_oi_planned abn_oi_unplanned acq_cost gas_stock)=
  abn_pct_oi abn_pct_bbg abn_pct_media abn_pct_oi_planned abn_pct_oi_unplanned acq_cost_vw gas_stock_vw;
run;


data x7;
merge x6 x5;
  by permno time;
  if firm_cap1k<ref_cap1k then firm_cap1k=ref_cap1k;
  ref_cap_pct=ref_cap1k/firm_cap1k;
  permno1=permno+0;
  format abn_pct_oi abn_pct_bbg abn_pct_media abn_pct_oi_planned abn_pct_oi_unplanned 10.3 acq_cost_vw gas_stock_vw 10.2 ref_cap_pct percent7.4; 
proc sort data=x7 nodupkey;
  by permno time;
run;



*merge firm quarterly financials;
proc sql noprint;
  create table x8 as select distinct a.*, b.datadate, b.rdq, b.ibq, b.debtq, 
  b.atq, b.bveq, b.mveq, b.atq_l1, b.bveq_l1 from
  x7 as a left join REFINERY.rr2_fundq as b
  on a.permno=b.permno & a.time>=b.rdq 
  group by a.permno1, a.time
  having intck('day',b.rdq,a.time)=min(intck('day',b.rdq,a.time));
quit;

proc sort data=x8 nodupkey;
  by permno time;
run;



*merge future stock returns;
proc sql noprint;
  create table x9 as select distinct a.*, b.* from
  x8 as a left join REFINERY.rr2_msf1 as b
  on a.permno1=b.permno & intck('month',a.time,b.date)=0
  group by a.permno, a.time;
quit;

proc sort data=x9 nodupkey;
  by permno time;
run;



*merge OIL index;
proc sql noprint;
  create table y1 as select distinct a.*, b.oil_index from
  x9 as a left join REFINERY.oil_index as b
  on b.beg_date<=a.time<=b.end_date;
quit;



data y1;
  informat permno time date1 hsiccd hexcd;
set y1;
  date1=intnx('month',time,1,'b');
  ibq_prc=ibq/mktcap_l1;
  roeq=ibq/bveq_l1;
  roaq=ibq/atq_l1;
  levq=debtq/atq;
  btmq=bveq/mveq;
  bve_mktcap_l1=bveq/mktcap_l1;
  tobinsq=(mktcap_l1+debtq)/(bveq+debtq);
  format oil_index 10.2 ibq_prc roaq roeq btmq bve_mktcap_l1 levq tobinsq 15.3 date1 mmddyy10.;
  drop date; rename date1=date;
proc sort data=y1 out=REFINERY.rr2_return_test_&interval nodupkey;
  by permno time;
run;


proc datasets library=work kill; 
run;quit;



*export SAS file to STATA file;
proc export data=REFINERY.rr2_return_test_&interval
  file="&Dropbox\Data\rr2_return_test_&interval"
  dbms=stata replace;
run;



